@@ -1,4 +1,8 @@
+import mmorph
+import text
 from mmorph import *
 from text import *
-__doc__ = mmorph.__doc__
 from pymorph_version import __version__
+
+__doc__ = mmorph.__doc__
+__all__ = mmorph.__all__ + ['text']
