@@ -122,7 +122,7 @@ mmsupcanon=supcanon
 mmsupgen=supgen
 mmsuprec=suprec
 mmswatershed=swatershed
-mmsymdif=symdif
+mmsymdif=symdiff
 mmtext=text
 mmthick=thick
 mmthin=thin
